# Vex MMM

### Open source library for building Marketing Mix Models.

Built for my own consulting projects and [www.vexpower.com](www.vexpower.com).

If you're new to MMM, learn by doing it in GSheets first ([link](https://www.saxifrage.xyz/post/econometrics-gsheets)).

Feel free to use for commercial and non-commercial uses (MIT License).

Contact me to contribute! [https://twitter.com/hammer_mt](https://twitter.com/hammer_mt)

Contributions Needed:

- Weibull Adstocks ([example](https://facebookexperimental.github.io/Robyn/docs/step-by-step-guide#guidance-to-set-hyperparameter-bounds))
- Media Optimization ([example](https://facebookexperimental.github.io/Robyn/docs/step-by-step-guide#using-the-budget-allocator))
- Bayesian Hierarchical Models ([example](https://research.google/pubs/pub45999/))
